@@ -78,7 +78,7 @@ SEXP write_worksheet_xml_2( std::string prior
   for(size_t i = 0; i < k; i++){
     
     cell_xml = "";
-    row_has_data = true;
+    row_has_data = false;
     
     while(current_row == unique_rows[i]){
       
@@ -134,59 +134,44 @@ SEXP write_worksheet_xml_2( std::string prior
       
     }
 
-    if ((h < n_row_heights) && (!Rf_isNull(row_heights_))) { // If there are custom row heights
+    // <row..> element has the following structure, where most components are optional:
+    //    <row r="1" ht="..." customHeight="1" outline_level="1" hidden="1">.....</row>
 
-      if ((l < n_outline_levels) && (!Rf_isNull(outline_levels_))) { // If there are grouped rows
-
-        if ((unique_rows[i] == row_heights_rows[h]) && (unique_rows[i] == outline_levels_rows[l]) && row_has_data) {
-          // Row is grouped and has a custom height
-          xmlFile << "<row r=\"" + unique_rows[i] + "\" ht=\"" + row_heights[h] + "\" customHeight=\"1\" outlineLevel=\"1\" hidden=\"" + outline_levels_hidden[l] + "\">" + cell_xml + "</row>";
-          h++;
-          l++;
-        } else if ((unique_rows[i] == outline_levels_rows[l]) && row_has_data) {
-          xmlFile << "<row r=\"" + unique_rows[i] + "\" outlineLevel=\"1\" hidden=\"" + outline_levels_hidden[l] + "\">" + cell_xml + "</row>";
-          l++;
-        } else if ((unique_rows[i] == row_heights_rows[h]) && row_has_data) {
-          // Row has custom height
-          xmlFile << "<row r=\"" + unique_rows[i] + "\" ht=\"" + row_heights[h] + "\" customHeight=\"1\">" + cell_xml + "</row>";
-          h++;
-        } else if (row_has_data) {
-          // Row has data
-          xmlFile << "<row r=\"" + unique_rows[i] + "\">" + cell_xml + "</row>";
-        } else {
-          xmlFile << "<row r=\"" + unique_rows[i] +  "\" ht=\"" + row_heights[h] + "\" customHeight=\"1\" outlineLevel=\"1\" hidden=\"" + outline_levels_hidden[l] +"\"/>";
-          h++;
-          l++;
-        }
-      } else {
-
-        if ((unique_rows[i] == row_heights_rows[h]) && row_has_data) {
-          xmlFile << "<row r=\"" + unique_rows[i] + "\" ht=\"" + row_heights[h] + "\" customHeight=\"1\">" + cell_xml + "</row>";
-          h++;
-        } else if (row_has_data) {
-          xmlFile << "<row r=\"" + unique_rows[i] + "\">" + cell_xml + "</row>";
-        } else {
-          xmlFile << "<row r=\"" + unique_rows[i] +  "\" ht=\"" + row_heights[h] + "\" customHeight=\"1\"/>";
-          h++;
-        }
-
+    // Handle one attribute after the other:
+    xmlFile << "<row r=\"" + unique_rows[i] + "\"";
+    // If there are custom row heights
+    if ((h < n_row_heights) && (!Rf_isNull(row_heights_)) && (unique_rows[i] == row_heights_rows[h])) {
+      xmlFile << " ht=\"" + row_heights[h] + "\" customHeight=\"1\"";
+      h++;
+    }
+    // If there are grouped rows
+    if ((l < n_outline_levels) && (!Rf_isNull(outline_levels_)) && (unique_rows[i] == outline_levels_rows[l])) {
+      xmlFile << " outlineLevel=\"" + outline_levels[l] + "\"";
+      // Ignore empty / null / NA values for hidden (accessing NULL would crash R / Rcpp!)
+      if ((outline_levels_hidden[l] != R_NilValue) && (outline_levels_hidden[l] != NA_STRING) && (outline_levels_hidden[l] != "")) {
+        xmlFile << " hidden=\"" + outline_levels_hidden[l] + "\"";
       }
-
-    } else if ((l < n_outline_levels) && (!Rf_isNull(outline_levels_))) {
-
-      if ((unique_rows[i] == outline_levels_rows[l]) && row_has_data) {
-        xmlFile << "<row r=\"" + unique_rows[i] + "\" outlineLevel=\"1\" hidden=\"" + outline_levels_hidden[l] + "\">" + cell_xml + "</row>";
-        l++;
-      } else if (row_has_data) {
-        xmlFile << "<row r=\"" + unique_rows[i] + "\">" + cell_xml + "</row>";
-      } else {
-        xmlFile << "<row r=\"" + unique_rows[i] + "\" outlineLevel=\"1\" hidden=\"" + outline_levels_hidden[l] + "\"/>";
-        l++;
+      l++;
+    }
+    // If the row has contents
+    if (row_has_data) {
+      xmlFile << ">" + cell_xml + "</row>";
+    } else {
+      xmlFile << "/>";
+    }
+    
+  }
+  
+  // All remaining grouped rows without content (ie. rows beyond the entries in unique_rows) need to be appended
+  if ((!Rf_isNull(outline_levels_))) {
+    while (l < n_outline_levels) {
+      xmlFile << "<row r=\"" + outline_levels_rows[l] + "\" outlineLevel=\"" + outline_levels[l] + "\"";
+      if ((outline_levels_hidden[l] != R_NilValue) && (outline_levels_hidden[l] != NA_STRING) && (outline_levels_hidden[l] != "")) {
+        xmlFile << " hidden=\"" + outline_levels_hidden[l] + "\"";
       }
-    } else {
-      xmlFile << "<row r=\"" + unique_rows[i] + "\">" + cell_xml + "</row>";
+      xmlFile << "/>";
+      l++;
     }
-
   }
     
   
